@@ -1,5 +1,8 @@
 package HTML::FormFu::Constraint::MaxRange;
-$HTML::FormFu::Constraint::MaxRange::VERSION = '2.01';
+
+use strict;
+our $VERSION = '2.05'; # VERSION
+
 use Moose;
 extends 'HTML::FormFu::Constraint::Range';
 
@@ -19,11 +22,15 @@ __END__
 
 HTML::FormFu::Constraint::MaxRange - Maximum Value Constraint
 
+=head1 VERSION
+
+version 2.05
+
 =head1 DESCRIPTION
 
 Checks the input value is equal to or less than a maximum value.
 
-Overrides L<HTML::FormFu::Constraint/localize_args>, so that the value of 
+Overrides L<HTML::FormFu::Constraint/localize_args>, so that the value of
 L</maximum> is passed as an argument to L<localize|HTML::FormFu/localize>.
 
 This constraint doesn't honour the C<not()> value.
