@@ -1,5 +1,8 @@
 package HTML::FormFu::Element::Blank;
-$HTML::FormFu::Element::Blank::VERSION = '2.01';
+
+use strict;
+our $VERSION = '2.05'; # VERSION
+
 use Moose;
 
 extends 'HTML::FormFu::Element';
@@ -41,11 +44,15 @@ __END__
 
 HTML::FormFu::Element::Blank - blank element
 
+=head1 VERSION
+
+version 2.05
+
 =head1 SEE ALSO
 
-Is a sub-class of, and inherits methods from 
-L<HTML::FormFu::Role::Element::Input>, 
-L<HTML::FormFu::Role::Element::Field>, 
+Is a sub-class of, and inherits methods from
+L<HTML::FormFu::Role::Element::Input>,
+L<HTML::FormFu::Role::Element::Field>,
 L<HTML::FormFu::Element>
 
 L<HTML::FormFu>
