@@ -1,7 +1,8 @@
 package HTML::FormFu::Element::Hidden;
-{
-  $HTML::FormFu::Element::Hidden::VERSION = '1.00';
-}
+
+use strict;
+our $VERSION = '2.05'; # VERSION
+
 use Moose;
 
 extends 'HTML::FormFu::Element';
@@ -12,28 +13,15 @@ after BUILD => sub {
     my $self = shift;
 
     $self->field_type('hidden');
-    $self->filename('input_tag');
+    $self->container_tag(undef);
+
+    $self->layout( [
+        'field',
+    ] );
 
     return;
 };
 
-sub string {
-    my ( $self, $args ) = @_;
-
-    $args ||= {};
-
-    my $render
-        = exists $args->{render_data}
-        ? $args->{render_data}
-        : $self->render_data;
-
-    # input template
-
-    my $html .= $self->_string_field($render);
-
-    return $html;
-}
-
 __PACKAGE__->meta->make_immutable;
 
 1;
@@ -44,6 +32,10 @@ __END__
 
 HTML::FormFu::Element::Hidden - Hidden form field
 
+=head1 VERSION
+
+version 2.05
+
 =head1 SYNOPSIS
 
     my $e = $form->element( Hidden => 'foo' );
@@ -56,9 +48,9 @@ Hidden form field.
 
 =head1 SEE ALSO
 
-Is a sub-class of, and inherits methods from 
-L<HTML::FormFu::Role::Element::Input>, 
-L<HTML::FormFu::Role::Element::Field>, 
+Is a sub-class of, and inherits methods from
+L<HTML::FormFu::Role::Element::Input>,
+L<HTML::FormFu::Role::Element::Field>,
 L<HTML::FormFu::Element>
 
 L<HTML::FormFu>
