@@ -1,5 +1,8 @@
 package HTML::FormFu::Element::Hr;
-$HTML::FormFu::Element::Hr::VERSION = '2.01';
+
+use strict;
+our $VERSION = '2.05'; # VERSION
+
 use Moose;
 
 extends 'HTML::FormFu::Element';
@@ -24,14 +27,18 @@ __END__
 
 HTML::FormFu::Element::Hr - horizontal-rule element
 
+=head1 VERSION
+
+version 2.05
+
 =head1 DESCRIPTION
 
 Horizontal-rule element.
 
 =head1 SEE ALSO
 
-Is a sub-class of, and inherits methods from 
-L<HTML::FormFu::Role::Element::NonBlock>, 
+Is a sub-class of, and inherits methods from
+L<HTML::FormFu::Role::Element::NonBlock>,
 L<HTML::FormFu::Element>
 
 L<HTML::FormFu>
