@@ -1,7 +1,8 @@
 package HTML::FormFu::Exception;
-{
-  $HTML::FormFu::Exception::VERSION = '1.00';
-}
+
+use strict;
+our $VERSION = '2.05'; # VERSION
+
 use Moose;
 
 with 'HTML::FormFu::Role::Populate';
