@@ -1,9 +1,10 @@
 package HTML::FormFu::Preload;
-{
-  $HTML::FormFu::Preload::VERSION = '1.00';
-}
 
 use strict;
+use warnings;
+
+our $VERSION = '2.05'; # VERSION
+
 use HTML::FormFu;
 
 use Module::Pluggable (
