@@ -1,5 +1,8 @@
 package HTML::FormFu::QueryType::CGI;
-$HTML::FormFu::QueryType::CGI::VERSION = '2.01';
+
+use strict;
+our $VERSION = '2.05'; # VERSION
+
 use Moose;
 
 extends 'HTML::FormFu::Upload';
@@ -11,6 +14,10 @@ sub parse_uploads {
     my ( $class, $form, $name ) = @_;
 
     my $query  = $form->query;
+    ## CGI wants you to use $query->multi_param($foo).
+    ## doing so breaks CGI::Simple. So shoosh it up for now.
+    local $CGI::LIST_CONTEXT_WARN = 0;
+
     my @params = $query->param($name);
     my @new;
 
@@ -61,6 +68,10 @@ __END__
 
 HTML::FormFu::QueryType::CGI - uploaded file
 
+=head1 VERSION
+
+version 2.05
+
 =head1 METHODS
 
 =head2 headers
@@ -94,7 +105,7 @@ Returns the browser-submitted Content-Type of the uploaded file.
 
 =head1 SEE ALSO
 
-Is a sub-class of, and inherits methods from 
+Is a sub-class of, and inherits methods from
 L<HTML::FormFu::Upload>
 
 L<HTML::FormFu>, L<HTML::FormFu::Element::File>
